from typing import Literal

COLOR_CATEGORY: Literal["color"] = "color"
SEGMENTATION_CATEGORY: Literal["segmentation"] = "segmentation"


LayerCategoryType = Literal["color", "segmentation"]
